@@ -1,6 +1,5 @@
 modelExtractParam <-
-function (model, only.values=TRUE,
-                               untransformed.values=FALSE) {
+function (model, only.values=TRUE, untransformed.values=FALSE) {
 #   if (any(.packages(all.available=TRUE)=="tigre") && is.GPModel(model))
 #     model <- modelStruct(model)
   
